from setuptools import setup, find_packages

setup(name="HttpMessageProcessor",
      version="0.12.0",
      packages=find_packages(where="."),
      install_requires=[
            'MessageProcessor==3.2.0',
            'SimpleHttpRouter==0.3.3',
            'iso8601==0.1.12',
            'inspect2==0.1.2;python_version<="2.7"',
            'enum34==1.1.10;python_version<="2.7"',
      ],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br")
